#ifndef UTILITIES_H
#define UTILITIES_H

#include <QString>

namespace Utils {

QString normalize(double d, const QString &unit);

};

#endif // UTILITIES_H
